;;
;; reminders.scm
;;
;; Email reminders.
;;
;; ISC License
;;
;; Copyright 2023 Brmlab, z.s.
;; Dominik Pantůček <dominik.pantucek@trustica.cz>
;;
;; Permission to use, copy, modify, and/or distribute this software
;; for any purpose with or without fee is hereby granted, provided
;; that the above copyright notice and this permission notice appear
;; in all copies.
;; 
;; THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
;; WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
;; WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE
;; AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR
;; CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
;; OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
;; NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
;; CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
;;

(declare (unit reminders))

(module
 reminders
 (
  make+print-reminder-email
  )

 (import scheme
	 (chicken base)
	 (chicken format)
	 member-record
	 util-mail
	 util-dict-list
	 members-payments
	 util-format)

 ;; Creates reminder email body
 (define (reminder-email-body mr)
   (list
    (member-format "Ahoj ~N," mr)
    "podle evidence členů a bankovního účtu to vypadá, že máš nedoplatek"
    (format "ve výši ~A Kč." (format-amount (member-total-balance mr)))
    "Zkontroluj, prosím, zda tvé platby členských příspěvků"
    (member-format "s variabilním symbolem ~I byly zaslány na" mr)
    "správný účet 1234/2010"
    ""
    ""
    (member-format "Hi ~N," mr)
    ""
    "--"
    "Brmlab Hackerspace Members Database"
    ))

 ;; Creates reminder email dictionary
 (define (make-reminder-email mr)
   (make-ldict
    `((to . ,(member-record-info mr 'mail))
      (subject . "Připomínka členských příspěvků / Membership fees reminder")
      (body . ,(reminder-email-body mr)))))

 ;; Prints email to the console
 (define (print-reminder-email em)
   (print "### From: " (ldict-ref em 'from "-"))
   (print "### To: " (ldict-ref em 'to))
   (print "### Subject: " (ldict-ref em 'subject))
   (let loop ((lines (ldict-ref em 'body)))
     (when (not (null? lines))
       (print (car lines))
       (loop (cdr lines)))))

 ;; Creates and prints reminder email for given member record
 (define (make+print-reminder-email mr)
   (print-reminder-email
    (make-reminder-email mr)))

 )
